@@ -37,7 +37,7 @@ Stone::Stone(const QString &stone, float value)
 {
     if (stone.size() >= 2) {
         m_x = stone[0].toUpper().toLatin1();
-        m_y = stone.mid(1).toInt();
+        m_y = stone.midRef(1).toInt();
     }
 }
 
@@ -77,4 +77,9 @@ QDebug operator<<(QDebug debug, const Stone &stone)
     return debug;
 }
 
+bool operator==(const Stone &stone, const Stone &other)
+{
+    return (stone.x() == other.x()) && (stone.y() == other.y());
+}
+
 } // End of namespace Kigo
