@@ -36,9 +36,7 @@
 #include <KNS3/DownloadDialog>
 #include <KStandardGameAction>
 #include <KToggleAction>
-#include <QUrl>
 #include <QIcon>
-#include <KHelpClient>
 #define USE_UNSTABLE_LIBKDEGAMESPRIVATE_API
 #include <libkdegamesprivate/kgamethemeselector.h>
 
@@ -273,7 +271,7 @@ void MainWindow::finishGame()
     //qDebug() << "Fetching final score from engine ...";
     Score score = m_game->estimatedScore();
     QString name;
-    if (score.color() == 'W') {
+    if (score.color() == QLatin1Char('W')) {
         name = m_game->whitePlayer().name() + " (White)";
     } else {
         name = m_game->blackPlayer().name() + " (Black)";
